package com.ruoyi.business.state.service;

import com.ruoyi.business.state.domain.StateModel;

import java.util.List;

/**
 * 调查问卷模板Service接口
 * 
 * @author Duke_yzl
 * @date 2023-06-26
 */
public interface IStateModelService 
{
    /**
     * 查询调查问卷模板
     * 
     * @param modelId 调查问卷模板主键
     * @return 调查问卷模板
     */
    public StateModel selectStateModelByModelId(Long modelId);

    /**
     * 查询调查问卷模板列表
     * 
     * @param stateModel 调查问卷模板
     * @return 调查问卷模板集合
     */
    public List<StateModel> selectStateModelList(StateModel stateModel);

    /**
     * 新增调查问卷模板
     * 
     * @param stateModel 调查问卷模板
     * @return 结果
     */
    public boolean insertStateModel(StateModel stateModel);

    /**
     * 修改调查问卷模板
     * 
     * @param stateModel 调查问卷模板
     * @return 结果
     */
    public boolean updateStateModel(StateModel stateModel);

    /**
     * 批量删除调查问卷模板
     * 
     * @param modelIds 需要删除的调查问卷模板主键集合
     * @return 结果
     */
    public boolean deleteStateModelByModelIds(Long[] modelIds);

    /**
     * 删除调查问卷模板信息
     * 
     * @param modelId 调查问卷模板主键
     * @return 结果
     */
    public boolean deleteStateModelByModelId(Long modelId);
}
